@@ -1,5 +1,5 @@
+import os
 import traceback
-import numpy as np
 import wget
 from aiohttp_retry import ExponentialRetry, RetryClient
 
@@ -59,7 +59,10 @@ class MinioBackend(BackendBase):
             else:
                 url = 'http://{}/{}/{}'.format(self.domain, self.default_bucket, '{}_{}'.format(bucket, bucket_name))
                 print('downloading {} -> {}'.format(url, download_path))
-                download_path = wget.download(url, download_path)
+
+                if os.path.isfile(download_path):
+                    os.remove(download_path)
+                wget.download(url, download_path)
                 return True, download_path
         except Exception as e:
             if tries >= 3:
