@@ -1,6 +1,6 @@
+import os
 import asyncio
 import traceback
-import numpy as np
 import wget
 from aiohttp_retry import ExponentialRetry, RetryClient
 
@@ -71,7 +71,10 @@ class WYSF(BackendBase):
             else:
                 url = 'http://{}/{}'.format(self.domain, '{}_{}'.format(bucket, bucket_name))
                 print('downloading {} -> {}'.format(url, download_path))
-                download_path = wget.download(url, download_path)
+
+                if os.path.isfile(download_path):
+                    os.remove(download_path)
+                wget.download(url, download_path)
                 return True, download_path
         except Exception as e:
             if tries >= 3:
